@@ -58,11 +58,9 @@
 
 BrowserWindow::BrowserWindow(const QString & config_path, QWidget * parent, Qt::WindowFlags flags)
 	: QMainWindow(parent, flags)
-	, preferred_quality(RetrieveYoutubeUrl::MP4_360p)
+	, preferred_resolution(RetrieveYoutubeUrl::R360p)
 	, use_cookies(true)
-#ifdef USE_PLAYERS
-	, current_player(-1)
-#endif
+	, current_player(Undefined)
 #ifdef D_BUTTON
 	, add_download_button(false)
 #endif
@@ -83,6 +81,7 @@ BrowserWindow::BrowserWindow(const QString & config_path, QWidget * parent, Qt::
 	connect(ryu, SIGNAL(gotEmptyList()), this, SLOT(showErrorEmptyList()));
 
 	ryua = new RetrieveYoutubeUrl(this);
+	ryua->setUseDASH(true);
 	connect(ryua, SIGNAL(gotUrls(const QMap<int, QString>&)), this, SLOT(openYTAudioUrl(const QMap<int, QString>&)));
 	connect(ryua, SIGNAL(signatureNotFound(const QString &)), this, SLOT(showErrorSignatureNotFound(const QString &)));
 	connect(ryua, SIGNAL(noSslSupport()), this, SLOT(showErrorNoSslSupport()));
@@ -100,6 +99,7 @@ BrowserWindow::BrowserWindow(const QString & config_path, QWidget * parent, Qt::
 
 	view = new MyWebView(this);
 	connect(view, SIGNAL(requestedOpenWith(const QString&, const QUrl&)), this, SLOT(openWith(const QString&, const QUrl&)));
+	connect(view, SIGNAL(requestedOpenWithBrowser(const QUrl&)), this, SLOT(openWithBrowser(const QUrl&)));
 	connect(view, SIGNAL(requestedOpenAudioWith(const QString&, const QUrl&)), this, SLOT(openAudioWith(const QString&, const QUrl&)));
 
 	view->setPage(page);
@@ -360,6 +360,26 @@ void BrowserWindow::processLink(const QUrl & url ) {
 	}
 }
 
+void BrowserWindow::fetchVideoUrl(RetrieveYoutubeUrl * ry, const QUrl & url, int player_id) {
+	current_player = player_id;
+	int resolution = preferred_resolution;
+
+	#ifdef USE_PLAYERS
+	if (player_id > -1) {
+		if (players.item(player_id).preferredResolution() != -1) {
+			resolution = players.item(player_id).preferredResolution();
+		}
+	}
+	#endif
+
+	#ifdef YT_USE_YTSIG
+	YTSig::setScriptFile(script_file);
+	#endif
+
+	ry->setPreferredResolution((RetrieveYoutubeUrl::Resolution) resolution);
+	ry->fetchPage(url.toString());
+}
+
 void BrowserWindow::openWith(int player_id, const QUrl & url) {
 	qDebug() << "BrowserWindow::openWith: player_id:" << player_id << "url:" << url.toString();
 
@@ -368,17 +388,12 @@ void BrowserWindow::openWith(int player_id, const QUrl & url) {
 	QString player_name = players.item(player_id).name();
 	QString arguments = players.item(player_id).arguments();
 	bool support_streaming_sites = players.item(player_id).supportStreamingSites();
-	bool support_online_tv = players.item(player_id).supportOnlineTV();
-	int quality = preferred_quality;
-	if (players.item(player_id).preferredQuality() != -1) {
-		quality = players.item(player_id).preferredQuality();
-	}
+	/* bool support_online_tv = players.item(player_id).supportOnlineTV(); */
 #else
 	QString binary = HCPLAYER_EXECUTABLE;
 	QString player_name = HCPLAYER_NAME;
 	QString arguments = HCPLAYER_ARGUMENTS;
 	bool support_streaming_sites = HCPLAYER_STREAMINGSITES;
-	int quality = preferred_quality;
 #endif
 
 	int site_type = SupportedUrls::site(url.toString());
@@ -394,13 +409,10 @@ void BrowserWindow::openWith(int player_id, const QUrl & url) {
 	} else {
 		qDebug() << "BrowserWindow::openWith:" << player_name << "can't play this URL";
 		#ifdef USE_PLAYERS
-		current_player = player_id;
+		fetchVideoUrl(ryu, url, player_id);
+		#else
+		fetchVideoUrl(ryu, url);
 		#endif
-		#ifdef YT_USE_YTSIG
-		YTSig::setScriptFile(script_file);
-		#endif
-		ryu->setPreferredQuality((RetrieveYoutubeUrl::Quality) quality);
-		ryu->fetchPage(url.toString());
 	}
 }
 
@@ -419,9 +431,24 @@ void BrowserWindow::openWith(const QString & player, const QUrl & url) {
 #endif
 }
 
+void BrowserWindow::openWithBrowser(const QUrl & url) {
+	qDebug() << "BrowserWindow::openWithBrowser: url:" << url.toString();
+	fetchVideoUrl(ryu, url, WebBrowser);
+}
+
 void BrowserWindow::openYTUrl(QString title, QString extension, const QString & url) {
 	qDebug() << "BrowserWindow::openYTUrl:" << url;
 
+	if (current_player == WebBrowser) {
+		QString u = url;
+		#if 1
+		u = "http://www.tonvid.com/video.php?u=" + url.toUtf8().toBase64().toPercentEncoding() +
+            "&t=" + title.toUtf8().toBase64().toPercentEncoding();
+		#endif
+		QDesktopServices::openUrl(u);
+		return;
+	}
+
 #ifdef USE_PLAYERS
 	if (current_player == -1) {
 		qDebug() << "BrowserWindow::openYTUrl: invalid player";
@@ -474,22 +501,21 @@ void BrowserWindow::openAudioWith(const QString & player, const QUrl & url) {
 
 	if (p != -1) {
 		#ifdef USE_PLAYERS
-		current_player = p;
+		fetchVideoUrl(ryua, url, p);
+		#else
+		fetchVideoUrl(ryua, url);
 		#endif
-		#ifdef YT_USE_YTSIG
-		YTSig::setScriptFile(script_file);
-		#endif
-		ryua->fetchPage(url.toString());
 	}
 }
 
 void BrowserWindow::openYTAudioUrl(const QMap<int, QString>& url_map) {
+	Q_UNUSED(url_map);
 	qDebug() << "BrowserWindow::openYTAudioUrl";
-	QString url;
-	int itag = ryua->findBestAudio(url_map);
-	if (itag != -1) url = url_map[itag];
 
-	//qDebug() << "BrowserWindow::openYTAudioUrl: url:" << url;
+	int itag = ryua->selectedQuality();
+	QString url = ryua->selectedAudioUrl();
+
+	qDebug() << "BrowserWindow::openYTAudioUrl: url:" << url << "itag:" << itag;
 
 	if (!url.isEmpty()) {
 		openYTUrl(ryua->urlTitle(), ryu->extensionForItag(itag), url);
@@ -566,7 +592,7 @@ void BrowserWindow::showAbout() {
 void BrowserWindow::showConfigDialog() {
 	ConfigDialog d(this);
 
-	d.setPlaybackQuality(preferred_quality);
+	d.setPlaybackResolution(preferred_resolution);
 	#ifdef USE_PLAYERS
 	d.setPlayers(players.allPlayers());
 	d.setDefaultPlayers(players.defaultPlayers());
@@ -584,7 +610,7 @@ void BrowserWindow::showConfigDialog() {
 #endif
 
 	if (d.exec() == QDialog::Accepted) {
-		preferred_quality = d.playbackQuality();
+		preferred_resolution = d.playbackResolution();
 		#ifdef USE_PLAYERS
 		players.setAllPlayers(d.players());
 		view->setPlayers(players.availablePlayers());
@@ -622,7 +648,7 @@ void BrowserWindow::saveConfig() {
 	settings->endGroup();
 
 	settings->beginGroup("General");
-	settings->setValue("playback_quality", preferred_quality);
+	settings->setValue("playback_resolution", preferred_resolution);
 	settings->setValue("user_agent", ryu->userAgent());
 	settings->setValue("use_https_main", ryu->useHttpsMain());
 	settings->setValue("use_https_vi", ryu->useHttpsVi());
@@ -679,7 +705,7 @@ void BrowserWindow::loadConfig() {
 	settings->endGroup();
 
 	settings->beginGroup("General");
-	preferred_quality = settings->value("playback_quality", RetrieveYoutubeUrl::MP4_360p).toInt();
+	preferred_resolution = settings->value("playback_resolution", RetrieveYoutubeUrl::R360p).toInt();
 	ryu->setUserAgent(settings->value("user_agent", "").toString());
 	ryu->setUseHttpsMain(settings->value("use_https_main", false).toBool());
 	ryu->setUseHttpsVi(settings->value("use_https_vi", false).toBool());
