@@ -30,10 +30,11 @@ MyWebView::MyWebView(QWidget * parent)
 	:QWebView(parent)
 	,context_menu(0)
 #ifdef USE_PLAYERS
+	,video_menu(0)
 	,audio_menu(0)
 #endif
 {
-	openLinkInExternalBrowserAct = new QAction(tr("Open link in a web browser"), this);
+	openLinkInExternalBrowserAct = new QAction(tr("Open in &YouTube"), this);
 	connect(openLinkInExternalBrowserAct, SIGNAL(triggered()), this, SLOT(openLinkInExternalBrowser()));
 }
 
@@ -44,12 +45,15 @@ void MyWebView::contextMenuEvent(QContextMenuEvent* event) {
 	qDebug() << "MyWebView::contextMenuEvent: url:" << url.toString();
 
 	// Translate and adjust some actions
+	pageAction(QWebPage::DownloadLinkToDisk)->setText(tr("&Save link..."));
 	pageAction(QWebPage::DownloadLinkToDisk)->setEnabled(false);
-	pageAction(QWebPage::DownloadLinkToDisk)->setText(tr("Save link..."));
-	pageAction(QWebPage::CopyLinkToClipboard)->setText(tr("Copy link to clipboard"));
+	pageAction(QWebPage::DownloadLinkToDisk)->setVisible(false);
+	pageAction(QWebPage::CopyLinkToClipboard)->setText(tr("Copy &link to clipboard"));
 	pageAction(QWebPage::OpenLink)->setText(tr("Open link in this window"));
-	pageAction(QWebPage::Copy)->setText(tr("Copy text to clipboard"));
-	pageAction(QWebPage::OpenLinkInNewWindow)->setText(tr("Open link in new window"));
+	pageAction(QWebPage::OpenLink)->setVisible(false);
+	pageAction(QWebPage::Copy)->setText(tr("&Copy text to clipboard"));
+	pageAction(QWebPage::OpenLinkInNewWindow)->setText(tr("Open link in &new window"));
+	pageAction(QWebPage::OpenLinkInNewWindow)->setVisible(false);
 
 	if (url.isEmpty()) {
 		QWebView::contextMenuEvent(event);
@@ -71,8 +75,13 @@ void MyWebView::createContextMenu(int site_id, const QUrl & url) {
 	context_menu->clear();
 
 #ifdef USE_PLAYERS
+	if (video_menu == 0) {
+		video_menu = new QMenu(tr("&Play with"), this);
+	}
+	video_menu->clear();
+
 	if (audio_menu == 0) {
-		audio_menu = new QMenu(tr("Open audio with"), this);
+		audio_menu = new QMenu(tr("Play &audio with"), this);
 	}
 	audio_menu->clear();
 
@@ -96,9 +105,9 @@ void MyWebView::createContextMenu(int site_id, const QUrl & url) {
 			if (media == Player::Video || media == Player::VideoAudio) {
 				QAction * videoAct = new QAction(this);
 				connect(videoAct, SIGNAL(triggered()), this, SLOT(openWithTriggered()));
-				videoAct->setText(tr("Open with %1").arg(player_list[n].name()));
+				videoAct->setText(player_list[n].name());
 				videoAct->setData(QStringList() << player_list[n].name() << url.toString());
-				context_menu->addAction(videoAct);
+				video_menu->addAction(videoAct);
 			}
 
 			// Audio
@@ -114,6 +123,10 @@ void MyWebView::createContextMenu(int site_id, const QUrl & url) {
 		}
 	}
 
+	if (!video_menu->isEmpty()) {
+		context_menu->addMenu(video_menu);
+	}
+
 	if (!audio_menu->isEmpty()) {
 		context_menu->addMenu(audio_menu);
 	}
@@ -121,18 +134,24 @@ void MyWebView::createContextMenu(int site_id, const QUrl & url) {
 #else
 	QAction * videoAct = new QAction(this);
 	connect(videoAct, SIGNAL(triggered()), this, SLOT(openWithTriggered()));
-	videoAct->setText(tr("Open with %1").arg(player_name));
+	videoAct->setText(tr("&Play with %1").arg(player_name));
 	videoAct->setData(QStringList() << player_name << url.toString());
 	context_menu->addAction(videoAct);
 
 	// Audio
 	QAction * audioAct = new QAction(this);
 	connect(audioAct, SIGNAL(triggered()), this, SLOT(openAudioWithTriggered()));
-	audioAct->setText(tr("Open audio with %1").arg(player_name));
+	audioAct->setText(tr("Play &audio with %1").arg(player_name));
 	audioAct->setData(QStringList() << player_name << url.toString());
 	context_menu->addAction(audioAct);
 #endif
 
+	QAction * playWithBrowserAct = new QAction(this);
+	connect(playWithBrowserAct, SIGNAL(triggered()), this, SLOT(openWithBrowserTriggered()));
+	playWithBrowserAct->setText(tr("Play video with a &web browser"));
+	playWithBrowserAct->setData(url.toString());
+	context_menu->addAction(playWithBrowserAct);
+
 	context_menu->addSeparator();
 
 	QAction *copy_link = pageAction(QWebPage::CopyLinkToClipboard);
@@ -161,6 +180,15 @@ void MyWebView::openWithTriggered() {
 	}
 }
 
+void MyWebView::openWithBrowserTriggered() {
+	qDebug() << "MyWebView::openWithBrowserTriggered";
+	QAction * a = qobject_cast<QAction *>(sender());
+	if (a) {
+		QString url = a->data().toString();
+		emit requestedOpenWithBrowser(url);
+	}
+}
+
 void MyWebView::openAudioWithTriggered() {
 	qDebug() << "MyWebView::openAudioWithTriggered";
 	QAction * a = qobject_cast<QAction *>(sender());
